
# Clase que representa un menú dietético
class Dietmenu
    include Comparable
    
    attr_accessor :vct, :proteinas, :grasas, :hidratos_carbono
    
    # Método que permite comparar dos menús dietéticos en base al vct (<,>,<=,>=)
    def <=>(other)
    	return nil unless other.is_a? Dietmenu
    	vct <=> other.vct
    end
    
    # Método que permite comparar si dos menús son iguales
    def ==(other)
    	return nil unless other.is_a? Dietmenu
    	if(vct==other.vct)
    		if(proteinas==other.proteinas)
    			if(grasas==other.grasas)
    				hidratos_carbono == other.hidratos_carbono
    			else
    				false
    			end
    		else
    			false
    		end
    	else
    		false
    	end
    end
    
    # Constructor de la clase, necesita un título de menú, un porcentaje, un conjunto de platos, el valor calorítico, las proteínas, las grasas e hidratos
	def initialize(titulo, porcentaje, platos, vct, proteinas, grasas, hidratos_carbono)
		@titulo = titulo
		@porcentaje = porcentaje
		@platos = platos
		@vct = vct
		@proteinas = proteinas
		@grasas = grasas
		@hidratos_carbono = hidratos_carbono
	end
	
	
	# Función que imprime por pantalla el menú
	def to_s

		string = "#{@titulo} (#{@porcentaje}) \n"
		
		for i in (0..@platos.length-1)
			string += "- #{@platos[i]} \n"
		end

		string += "V.C.T | %	#{@vct} kcal | #{@proteinas} - #{@grasas} - #{@hidratos_carbono}\n"

		string


	end
	
	# Método que obtiene el titulo del menú
	def get_titulo
		@titulo
	end

	# Método que obtiene el porcentaje del menú
	def get_porcentaje
		@porcentaje
	end

	# Método que obtiene el vector del conjunto de platos
	def get_platos
		@platos
	end

	# Método que obtiene el plato en la posición n_plato del vector platos
	def get_plato(n_plato)
		platos[n_plato]
	end

	# Método que obtiene el valor calorítico
	def get_vct
		@vct
	end

	# Método que obtiene las proteínas del menú
	def get_proteinas
		@proteinas
	end

	# Método que obtiene las grasas del menú
	def get_grasas
		@grasas
	end
	
	# Método que obtiene los hidratos del menú
	def get_hidratos
		@hidratos_carbono
	end
end

# Clase que representa un plato del menú
class Plato
    attr_reader :titulo, :porcion, :gramos
    # Constructor de la clase plato, necesita un título de plato, una porción y sus gramos
	def initialize(titulo, porcion, gramos)
		@titulo = titulo
		@porcion = porcion
		@gramos = gramos
	end
	
	# Método que formatea los datos de un plato
    def to_s
		"#{@titulo}, #{@porcion}, #{@gramos}"
    end
	
	# Método que obtiene el título de un plato
    def get_titulo
        @titulo
    end

	# Método que obtiene la porción de un plato
	def get_porcion
		@porcion
	end

	# Método que obtiene los gramos de un plato
	def get_gramos
		@gramos
	end
end


# Clase hija de menú dietético que los agrupa por tipo de alimento
class GrAlimento < Dietmenu
	
	attr_reader :alimento
	# Constructor de la clase GrAlimento que dentro llama al initialize de la superclase con super
	def initialize(alimento,titulo, porcentaje, platos, vct, proteinas, grasas, hidratos_carbono)
		super(titulo, porcentaje, platos, vct, proteinas, grasas, hidratos_carbono)
		@alimento = alimento
	end
	
	
	#Método que obtienee la categoría del menú
	def get_categoria
		@alimento
	end
	
	# Método que formatea la categoría con su respectivo menú usando super
	def to_s
		pintar = "#{@alimento}\n"
		pintar += super.to_s
	end
end

# Clase hija de menú dietético que los agrupa por edades
class GrEdad < Dietmenu
	
	attr_reader :redad
	
	# Constructor de la clase GrEdad que dentro llama al initialize de la superclase con super
	def initialize(redad,titulo, porcentaje, platos, vct, proteinas, grasas, hidratos_carbono)
		super(titulo, porcentaje, platos, vct, proteinas, grasas, hidratos_carbono)
		@redad = redad
	end
	
	# Método que obtienee el rango de edades del menú
	def get_redad
		@redad
	end
	
	# Método que formatea la edad con su respectivo menú usando super
	def to_s
		pintar = "#{@redad[0]} a #{@redad[1]} años\n"
		pintar += super.to_s
	end
end